@@ -1,7 +1,7 @@
 def test
   connection = Fog::Google::SQL.new
 
-  puts 'Listing all Flags...'
-  puts '--------------------'
+  puts "Listing all Flags..."
+  puts "--------------------"
   connection.flags
 end
