@@ -26,6 +26,7 @@ module Fog
         # These attributes are not available in the representation of an 'instance' returned by the GCE API.
         # They are useful only for the create process
         attribute :network, :aliases => "network"
+        attribute :subnetwork, :aliases => "subnetwork"
         attribute :external_ip, :aliases => "externalIP"
         attribute :auto_restart
         attribute :on_host_maintenance
@@ -162,9 +163,17 @@ module Fog
           data.body["contents"]
         end
 
-        def set_disk_auto_delete(auto_delete, device_name)
+        def set_disk_auto_delete(auto_delete, device_name = nil)
           requires :identity, :zone
 
+          unless device_name
+            if disks.count <= 1
+              device_name = disks[0]["deviceName"]
+            else
+              raise ArgumentError.new("Device name required if multiple disks are attached")
+            end
+          end
+
           data = service.set_server_disk_auto_delete(identity, zone_name, auto_delete, device_name)
           Fog::Compute::Google::Operations.new(:service => service).get(data.body["name"], data.body["zone"])
         end
@@ -190,6 +199,10 @@ module Fog
           Fog::Compute::Google::Operations.new(:service => service).get(data.body["name"], data.body["zone"])
         end
 
+        def provisioning?
+          state == PROVISIONING
+        end
+
         def ready?
           state == RUNNING
         end
@@ -199,17 +212,7 @@ module Fog
         end
 
         def add_ssh_key(username, key)
-          self.metadata = Hash.new("") if metadata.nil?
-
-          # You can have multiple SSH keys, seperated by newlines.
-          # https://developers.google.com/compute/docs/console?hl=en#sshkeys
-          metadata["sshKeys"] = "" unless metadata["sshKeys"]
-
-          metadata["sshKeys"] += "\n" unless metadata["sshKeys"].empty?
-
-          metadata["sshKeys"] += "#{username}:#{key.strip}"
-
-          metadata
+          set_metadata(generate_ssh_key_metadata(username, key))
         end
 
         def map_service_accounts(scope_array)
@@ -247,12 +250,13 @@ module Fog
             raise ArgumentError.new "#{zone_name.inspect} is either down or you don't have permission to use it."
           end
 
-          add_ssh_key(username, public_key) if public_key
+          generate_ssh_key_metadata(username, public_key) if public_key
 
           options = {
             "machineType" => machine_type,
             "networkInterfaces" => network_interfaces,
             "network" => network,
+            "subnetwork" => subnetwork,
             "externalIp" => external_ip,
             "disks" => disks,
             "metadata" => metadata,
@@ -277,6 +281,26 @@ module Fog
           operation.wait_for { !pending? }
           reload
         end
+
+        private
+
+        def generate_ssh_key_metadata(username, key)
+          self.metadata = Hash.new("") if metadata.nil?
+
+          # The key "sshKeys" is deprecated and will be unsupported in the
+          # future - for now defer to using 'ssh-keys' unless the user is
+          # already using the deprecated version
+          # https://cloud.google.com/compute/docs/instances/adding-removing-ssh-keys#deprecated
+          metadata_key = metadata.key?("sshKeys") ? "sshKeys" : "ssh-keys"
+
+          # You can have multiple SSH keys, seperated by newlines.
+          # https://developers.google.com/compute/docs/console?hl=en#sshkeys
+          metadata[metadata_key] = "" unless metadata[metadata_key]
+          metadata[metadata_key] += "\n" unless metadata[metadata_key].empty?
+          metadata[metadata_key] += "#{username}:#{key.strip}"
+
+          metadata
+        end
       end
     end
   end
