@@ -16,22 +16,8 @@ module Fog
 
         def all(options = {})
           requires :directory
-          options = {
-            "delimiter"   => delimiter,
-            "pageToken"   => page_token,
-            "maxResults"  => max_results,
-            "prefix"      => prefix
-          }.merge!(options)
-          options = options.reject { |_key, value| value.nil? || value.to_s.empty? }
-          merge_attributes(options)
-          parent = directory.collection.get(
-            directory.key,
-            options
-          )
-          if parent
-            merge_attributes(parent.files.attributes)
-            load(parent.files.map(&:attributes))
-          end
+
+          load(service.list_objects(directory.key, options)[:body]["items"])
         end
 
         alias_method :each_file_this_page, :each
@@ -42,10 +28,6 @@ module Fog
             subset = dup.all
 
             subset.each_file_this_page { |f| yield f }
-            while subset.is_truncated
-              subset = subset.all(:marker => subset.last.key)
-              subset.each_file_this_page { |f| yield f }
-            end
 
             self
           end
@@ -61,7 +43,7 @@ module Fog
           file_data.merge!(:body => data.body,
                            :key  => key)
           new(file_data)
-        rescue Excon::Errors::NotFound
+        rescue Fog::Errors::NotFound
           nil
         end
 
@@ -75,7 +57,7 @@ module Fog
           data = service.head_object(directory.key, key, options)
           file_data = data.headers.merge(:key => key)
           new(file_data)
-        rescue Excon::Errors::NotFound
+        rescue Fog::Errors::NotFound
           nil
         end
 
