@@ -24,7 +24,7 @@ module TestCollection
   end
 
   def test_get_returns_nil_if_resource_does_not_exist
-    assert_nil @subject.get('fog-test-fake-identity')
+    assert_nil @subject.get("fog-test-fake-identity")
   end
 
   def test_enumerable
