@@ -13,9 +13,9 @@ class ServersFactory < CollectionFactory
   end
 
   def params
-    params = { :name => resource_name,
-               :zone_name => TEST_ZONE,
-               :machine_type => TEST_MACHINE_TYPE,
-               :disks => [@disks.create] }
+    { :name => resource_name,
+      :zone_name => TEST_ZONE,
+      :machine_type => TEST_MACHINE_TYPE,
+      :disks => [@disks.create] }
   end
 end
