@@ -1,12 +1,9 @@
-Shindo.tests('Fog::Google[:sql] | tiers model', ['google']) do
+Shindo.tests("Fog::Google[:sql] | tiers model", ["google"]) do
   @tiers = Fog::Google[:sql].tiers
 
-  tests('success') do
-
+  tests("success") do
     tests('#all').succeeds do
       @tiers.all
     end
-
   end
-
 end
